/*! Copyright 2023-2024 the gnablib contributors MPL-1.1 */
import { FromBinResult } from '../../primitive/FromBinResult.js';
import { ColType } from './ColType.js';
import { ACudColType } from './ACudColType.js';
import type { IValid } from '../interfaces/IValid.js';
import { IProblem } from '../../error/probs/interfaces/IProblem.js';
declare abstract class AFloat extends ACudColType implements IValid<number> {
    constructor(nullable?: boolean);
    valid(input?: number): IProblem | undefined;
    protected _binUnknown(bin: Uint8Array, pos: number, byteSize: number): FromBinResult<Uint8Array | undefined>;
}
export declare class Float4 extends AFloat {
    readonly mysqlType = "FLOAT";
    readonly sqliteType = "FLOAT";
    readonly postgresType = "real";
    readonly cudType = "float4";
    readonly _colType = ColType.Float4;
    cudByteSize(): number;
    unknownBin(value?: number): Uint8Array;
    binUnknown(bin: Uint8Array, pos: number): FromBinResult<number | undefined>;
}
export declare class Float8 extends AFloat {
    readonly mysqlType = "DOUBLE";
    readonly sqliteType = "DOUBLE";
    readonly postgresType = "double precision";
    readonly cudType = "float8";
    readonly _colType = ColType.Float8;
    cudByteSize(): number;
    unknownBin(value?: number): Uint8Array;
    binUnknown(bin: Uint8Array, pos: number): FromBinResult<number | undefined>;
}
export {};
